=======
Credits
=======

Development Lead
----------------

* Ivan Ogasawara <ivan.ogasawara@gmail.com>
* Marcelo Gomes <marfcg@gmail.com>
* Flavio Coelho <fccoelho@gmail.com>

Contributors
------------

None yet. Why not be the first?
